@@ -6,17 +6,17 @@ function(mat,bases,geno=1:3){
 	ids<-bb>aa
 	if(sum(ids)>0){
 		tmp<-mat[ids,]
-		tmp[tmp==oldgeno[4]]<-1
-		tmp[tmp==oldgeno[1]]<-3
+		tmp[tmp==oldgeno[4]]<-geno[1]
+		tmp[tmp==oldgeno[1]]<-geno[3]
 		mat[ids,]<-tmp
 	}
 	if(sum(ids)<length(ids)){
 		tmp<-mat[!ids,]
-		tmp[tmp==oldgeno[4]]<-3
-		tmp[tmp==oldgeno[1]]<-1
+		tmp[tmp==oldgeno[4]]<-geno[3]
+		tmp[tmp==oldgeno[1]]<-geno[1]
 		mat[!ids,]<-tmp
 	}
-	mat[mat%in%oldgeno[2:3]]<-2
+	mat[mat%in%oldgeno[2:3]]<-geno[2]
 	mat
 }
 
