@@ -148,10 +148,8 @@ function(n.obs,n.snp,vec.ia,prop.explain=1,list.ia.val=NULL,vec.ia.num=NULL,vec.
 	mat2<-as.data.frame(mat)
 	vec.cases<-vec.controls<-numeric(n.ia)
 	mat.eval <- matrix(0, n.obs, n.ia)
-	attach(mat2)
 	for(i in 1:n.ia)
-		mat.eval[,i] <- eval(parse(text=ias[i]))
-	detach(mat2)
+		mat.eval[,i] <- with(mat2, eval(parse(text=ias[i])))
 	vec.cases <- colSums(mat.eval[y==1,])
 	vec.controls <- colSums(mat.eval[y==0,])
 	if(any(vec.cases!=vec.ia.num))
